jb library

Classes

CompilationPath
Java compilation path.
CompileOutput
Compilation output destination.
ConfigSource
CreateOptions
The 'create' command options.
DependencyLicense
DependencySpec
Specification of a dependency.
DependencyWarning
Developer
A developer entry.
ExtensionProject
ExtensionTask
Definition of a jb extension task.
ExtensionTaskExtra
The extra config for a jb task obtained by instantiating the Java task and calling getSummary().
FileConfigSource
FileDeps
FileDiff
FileTree
A tree of files describing source files' dependencies.
InstanceConfigSource
Jar
Java Module information.
JarDependency
JbCliOptions
JbConfigContainer
A container holding an instance of the generated type JbConfiguration as well as a computed CompileOutput.
JbConfiguration
jb configuration model.
JbDartle
jb Dartle build definition.
JbExtensionModel
jb extension model.
JbExtensionModelBuilder
License
A SPDX License.
LocalDependencies
Grouping of all local dependencies, which can be local JarDependency or ProjectDependencys.
Module
Java Module information.
PathDependency
A dependency that refers to a local path.
ProjectDependency
Requirement
A Java module requirement.
ResolvedDependencies
ResolvedDependency
ResolvedLocalDependencies
ResolvedProjectDependency
SourceControlManagement
Source control Management settings.
TransitiveChanges
VersionConflict

Enums

ConfigType
The jb configuration value's types.
DependencyScope

Properties

depsPhase → TaskPhase
final
evaluatePhase → TaskPhase
final
logger → Logger
final
publishPhase → TaskPhase
final

Functions

computeAllChanges(ChangeSet? changeSet, File srcFileTree) Future<TransitiveChanges?>
createArtifact(JbConfiguration config) → Result<Artifact>
createCompileTask(JbFiles jbFiles, JbConfigContainer config, CompilationPathFiles compPathFiles, DartleCache cache, JbActors actors) → Task
Create the compile task.
createDepsTask(JbFiles jbFiles, JbConfiguration config, DepsCache depsCache, DartleCache cache, ResolvedLocalDependencies localDeps, ResolvedLocalDependencies localProcDeps) → Task
Create the dependencies task.
createDownloadTestRunnerTask(JbFiles files, JbConfigContainer configContainer, JBuildSender jBuildSender, DepsCache depsCache, DartleCache cache, FileCollection jbFileInputs) → Task
Create the downloadTestRunner task.
createEclipseTask(JbConfiguration config) → Task
Create the eclipse task.
createGeneratePomTask(Result<Artifact> artifact, ResolvedLocalDependencies localDependencies, File dependenciesFile, DepsCache depsCache) → Task
Create the generatePom task.
createIfNeededAndGetJBuildJarFile() Future<File>
createInstallCompileDepsTask(JbFiles files, JbConfiguration config, JBuildSender jBuildSender, DepsCache depsCache, DartleCache cache, ResolvedLocalDependencies localDependencies) → Task
Create the installCompileDependencies task.
createInstallProcessorDepsTask(JbFiles files, JbConfiguration config, JBuildSender jBuildSender, DepsCache depsCache, DartleCache cache, ResolvedLocalDependencies localDependencies) → Task
Create the installProcessorDependencies task.
createInstallRuntimeDepsTask(JbFiles files, JbConfigContainer config, JBuildSender jBuildSender, DepsCache depsCache, DartleCache cache, ResolvedLocalDependencies localDependencies) → Task
Create the installRuntimeDependencies task.
createJavaCompilationPathTask(JbFiles files, JbConfigContainer config, JBuildSender jBuildSender, Sendable<CompilationPathMessage, CompilationPath?> compPath, CompilationPathFiles compilationFiles) → Task
createJavaRuntimePathTask(JbFiles files, JbConfigContainer config, JBuildSender jBuildSender, Sendable<CompilationPathMessage, CompilationPath?> compPath, CompilationPathFiles compilationFiles) → Task
createJshellTask(JbFiles files, JbConfigContainer config, DartleCache cache) → Task
Create the jshell task.
createNewProject(List<String> arguments, {bool colors = true}) Future<void>
Create a new jb project.
createPom(Artifact artifact, Iterable<ResolvedDependency> dependencies, ResolvedLocalDependencies localDependencies) String
Create a Maven POM for publishing purposes.
createPublicationCompileTask(JbFiles jbFiles, JbConfigContainer config, CompilationPathFiles compPathFiles, DartleCache cache, JbActors actors) → Task
Create the publicationCompile task.
createPublishTask(Result<Artifact> artifact, File depsFile, DepsCache depsCache, String? outputJar, ResolvedLocalDependencies localDependencies) → Task
Create the publish task.
createRequirementsTask(File jbuildJar, JbConfigContainer config) → Task
Create the requirements task.
createRunTask(JbFiles files, JbConfigContainer config, DartleCache cache, JbActors actors, CompilationPathFiles compilationFiles) → Task
Create the run task.
createShowConfigTask(JbConfiguration config, bool noColor) → Task
createTestConfig(Iterable<MapEntry<String, DependencySpec>> dependencies) TestConfig
Find Testing framework information from a jb project dependencies.
createTestTask(File jbuildJar, JbConfigContainer config, DartleCache cache, bool noColor) → Task
Create the test task.
createUpdateJBuildTask(JBuildSender jBuildSender) → Task
createVerifyDependenciesTask(JbFiles jbFiles, DepsCache depsCache, DartleCache cache) → Task
createWriteDependenciesTask(JbFiles jbFiles, JbConfiguration config, ResolvedLocalDependencies localDependencies, ResolvedLocalDependencies localProcessorDependencies, DepsCache depsCache, DartleCache cache, FileCollection jbFileInputs, JBuildSender jbuildSender) → Task
Create the writeDependencies task.
execJava(String taskName, List<String> args, {ProcessOutputConsumer? onStdout, ProcessOutputConsumer? onStderr, Map<String, String> env = const {}}) Future<int>
Execute a java process.
execJBuild(String taskName, File jbuildJar, List<String> preArgs, String command, List<String> commandArgs, {ProcessOutputConsumer? onStdout, ProcessOutputConsumer? onStderr, Map<String, String> env = const {}}) Future<int>
Execute the jbuild tool.
findTestRunnerLib(ResolvedDependencies resolvedDeps) String?
Get the dependency coordinates for the JUnit ConsoleLauncher.
invalidLicense(Iterable<String> ids) Exception
jbuildCliHome() String
Find the jb home directory.
jbuildJarPath() String
The jbuild.jar path. This jar is created, if necessary, from the embedded jar in jb, but may be updated.
junitTestSubcommand(String junitLauncherDir) Future<String?>
Find out the JUnit Launcher subcommand to use.
loadConfig(File configFile) Future<JbConfiguration>
Parse the YAML/JSON jbuild file.
loadConfigString(String config) Future<JbConfiguration>
Parse the YAML/JSON jb configuration.
loadExtensionProject(JbFiles files, JbActors actors, Options options, JbConfiguration config, DartleCache cache) Future<ExtensionProject?>
Load an extension project from the given projectPath, if given, or from the default location otherwise.
loadExtensionTaskConfigs(JbConfiguration jbConfig, String config, Uri yamlUri) Future<List<BasicExtensionTask>>
Parse the YAML/JSON jb extension model.
loadFileTree(Stream<String> requirements) Future<FileTree>
loadFileTreeFrom(File file) Future<FileTree>
runJb(JbCliOptions jbOptions, Options dartleOptions, [ConfigSource? configSource]) Future<bool>
Run jb.
spockRunnerLib(TestConfig testConfig) String
Dependency coordinates for the Spock Test Runner.
storeNewFileTree(String taskName, JbConfiguration config, String workingDir, JBuildSender jBuildSender, String buildOutput, File fileTreeFile) Future<void>
validateTestConfig(TestConfig config) → void
Validate that the test configuration is valid for running tests.

Typedefs

Artifact = ({String? description, List<Developer> developers, String group, List<License> licenses, String module, String name, SourceControlManagement? scm, String? url, String version})
Maven artifact.
BasicExtensionTask = ({String className, List<JavaConstructor> constructors, String description, String methodName, String name, TaskPhase phase})
Basic definitions of a jb extension task configuration.
JavaConstructor = Map<String, ConfigType>
Java constructor representation.
NullableInt = int?
TestConfig = ({String? apiVersion, String? platformVersion, String? spockVersion})
Testing Framework information.